'use strict';

loadsimpleSVG("logo-pd-height", "logo-container")
loadsimpleSVG("nav-open-button-up", "nav-open-button")

// Load SVGs and initialize event listeners
loadsimpleSVG("logo-pd-height", "logo-container", function() {
    loadsimpleSVG("nav-open-button", "nav-open-button", function() {
        DOMLoadedSpinExplore();
        DOMLoadedActivateNav();
        DOMLoadedActivateNavSelection();
    });
});

document.addEventListener('scroll', function() {
    const wheel = document.getElementById('wheel');
    const rotation = window.scrollY % 360; // Get scroll position and use modulo for rotation degree
    wheel.style.transform = `rotate(${rotation}deg)`;
});
function DOMLoadedSpinExplore() {
    const curveText = document.getElementById('curveText-nav');
    let slowRotation = 0;

    function rotateSlowly() {
        slowRotation += 0.03;
        curveText.style.transform = `rotate(${slowRotation}deg)`;
    // Add the missing opening parenthesis
    }

    const slowRotationInterval = setInterval(rotateSlowly, 1);
}
// Navigiations

function DOMLoadedActivateNav() {
    const navButton = document.getElementById('nav-open-button');
    const secondNavButton = document.getElementsByClassName('menu-phone-button')[0];
    const navOverlay = document.getElementById('nav-wrapperOverlay');
    const closeButton = document.getElementById('nav-close-button');
    const closeButtonMobile = document.getElementById('nav-close-button-mobile');
    const polGroup = document.querySelectorAll('.nav-PolygonGroup');
    const logo = document.querySelector('.logo-wrapper');
    const navExplorer = document.querySelector('.exploreNav');
    const navHome = document.querySelector('.nav-HomeItems');


    document.querySelectorAll('.hyperlink-subgroup').forEach(element => {
        element.addEventListener('click', function() {
            const href = this.getAttribute('data-href');
            if (href.startsWith("~/")) {
                href = href.replace("~", window.location.origin);
            }

            window.location.href = href;
        });
    });

    navButton.addEventListener('click', function() {
        document.body.style.overflow = 'hidden'; // Prevent scrolling

        navOverlay.classList.add('active');
        closeButton.classList.add('active');
        closeButtonMobile.classList.add('active');
        logo.classList.add('active');
        navExplorer.classList.add('active');

        polGroup.forEach((pol) => {
            pol.classList.add('active');
        });


    });

    secondNavButton.addEventListener('click', function() {
        document.body.style.overflow = 'hidden'; // Prevent scrolling

        navOverlay.classList.add('active');
        closeButton.classList.add('active');
        closeButtonMobile.classList.add('active');
        logo.classList.add('active');
        navExplorer.classList.add('active');

        polGroup.forEach((pol) => {
            pol.classList.add('active');
        });


    });
    
    function addShimmerClassToSvgPaths() {
        const navPolygons = document.querySelectorAll('.nav-polygon');
        navPolygons.forEach((element, index) => {
            if (index < 5) {
                setTimeout(() => {
                    element.classList.add('shimmer1');
                }, 700);
            }
            if (index > 5 && index < 13) {
                setTimeout(() => {
                    element.classList.add('shimmer2');
                }, 700);
            }
            if (index > 13 && index < 20) {
                setTimeout(() => {
                    element.classList.add('shimmer3');
                }, 700);
            }
            if (index < 21) {
                const delay = (index + 1) * 0.05 + 0.05;
                element.style.animationDelay = `${delay}s`;
            }
        });
    }

    addShimmerClassToSvgPaths();

    function closeNav() {
        navOverlay.classList.remove('active');
        navOverlay.classList.add('closing');
        navExplorer.classList.remove('active');
        logo.classList.remove('active');
        closeButton.classList.remove('active');
        closeButtonMobile.classList.remove('active');

        setTimeout(function() {
            navOverlay.classList.remove('closing');
        }, 1400);

        polGroup.forEach((pol) => {
            pol.classList.remove('active');
        });

        setTimeout(function() {
            document.body.style.overflow = ''; // Restore scrolling
        }, 1400);
    }

    closeButton.addEventListener('click', closeNav);
    closeButtonMobile.addEventListener('click', closeNav);

    document.addEventListener('keydown', function(event) {
        if ((event.key === 'Escape' || event.key === 'Esc') && navExplorer.classList.contains('active')) {
            closeNav();
        }
    });

    navHome.addEventListener('click', function(e) {
        closeNav()
        setTimeout(function() {
            e.preventDefault();
            const pathArray = window.location.pathname.split('/');

            pathArray.pop();

            let newPath = pathArray.join('/');

            newPath = newPath.endsWith('/') ? newPath + 'home' : newPath + '/home';
            window.location.href = newPath;
        }, 777);
    });
};



// Navigation Selection
function DOMLoadedActivateNavSelection() {
    const navItems = document.querySelectorAll('.nav-ItemGroup'); // Find the Nav Groups in SVG
    const allNavBalls = document.querySelectorAll('.nav-Ball');
    const allNavSubcircles = document.querySelectorAll('.nav-Subcircle'); // Find all the Balls/Circles in SVG for removing active class
    const navHyperlinks = document.querySelectorAll('.hyperlinkGroup');
    const navPreview = document.querySelector('.preview-group');

    let isProcessing = false;

    navItems.forEach((item, index) => {
        let clickCount = 0; // Track click count for each nav item

        item.addEventListener('click', function(event) {
            if (isProcessing) return; // If already processing, do nothing
            isProcessing = true;
            event.stopPropagation();

            clickCount++; // Increment click count

            if (clickCount === 2) {
                // Reset to preview state on double click
                navPreview.classList.add('active');
                allNavBalls.forEach((ball) => ball.classList.remove('active'));
                allNavSubcircles.forEach((subcircle) => subcircle.classList.remove('active'));
                navHyperlinks.forEach((link) => link.classList.remove('active'));

                clickCount = 0; // Reset click count for next interaction

                setTimeout(function() {
                    isProcessing = false;
                }, 400);

                return; // Exit function to skip the rest of the code for single click handling
            }

            // Existing code for single click handling
            navPreview.classList.remove('active');
            var clickedHyperlinkGroup = navHyperlinks[index]; // Find the correct Hyperlink Group with index from NavGroup (same Indice)
            var activeBall = item.querySelector('.nav-Ball'); // Find the Ball in the clicked Nav Group
            var activeSubcircle = item.querySelector('.nav-Subcircle'); // Find the Subcircle in the clicked Nav Group

            allNavBalls.forEach((ball) => {
                ball.classList.remove('active');
            });
            allNavSubcircles.forEach((subcircle) => {
                subcircle.classList.remove('active');
            });

            activeBall.classList.add('active');
            activeSubcircle.classList.add('active');

            // From the Hyperlink Group, find already active / secondary for fade out animations
            navHyperlinks.forEach((hyperlink) => {
                const activeHyperPrim = hyperlink.querySelectorAll(".primary.active");
                const activeHyperSec = hyperlink.querySelectorAll(".secondary.active");

                activeHyperPrim.forEach((primary) => {
                    primary.classList.add('inactive');
                });
                activeHyperPrim.forEach((primary) => {
                    primary.classList.remove('active');
                });

                activeHyperSec.forEach((secondary) => {
                    secondary.classList.add('inactive');
                });
                activeHyperSec.forEach((secondary) => {
                    secondary.classList.remove('active');
                });

                setTimeout(function() {
                    activeHyperSec.forEach((secondary) => {
                        secondary.classList.remove('inactive');
                    });
                    activeHyperPrim.forEach((primary) => {
                        primary.classList.remove('inactive');
                    });
                }, 400);
            });

            // Activate clicked Hyperlink Group
            setTimeout(function() {
                navHyperlinks.forEach((link) => {
                    link.classList.remove('active');
                });
                clickedHyperlinkGroup.classList.add('active');
                // Add active class to primary / secondary of the clicked Hyperlink Group
                var clickedHyperPrim = clickedHyperlinkGroup.querySelectorAll(".primary");
                var clickedHyperSec = clickedHyperlinkGroup.querySelectorAll(".secondary");

                clickedHyperPrim.forEach((primary) => {
                    primary.classList.add('active');
                });
                clickedHyperSec.forEach((secondary) => {
                    secondary.classList.add('active');
                });
            }, 400);

            setTimeout(function() {
                isProcessing = false;
            }, 400);
        });
    });
}

$(document).ready(function() {
    const pageNames = {
        'description': 'Project Description',
        'engineering': 'Engineering',
        'safety': 'Safety',
        'contribution': 'Contribution',
        'model': 'Model',
        'software': 'Software',
        'experiments': 'Experiments',
        'results': 'Results',
        'notebook': 'Notebook',
        'parts': 'Parts',
        'human-practices': 'Human Practices',
        'public-engagement': 'Public Engagement',
        'education': 'Education',
        'gallery': 'Art Gallery',
        'team': 'Team Member',
        'attributions': 'Attributions',
        'application': 'Applications',
    };
    const currentPath = window.location.pathname.split('/').pop();

    if (pageNames[currentPath]) {
        $('.hero-title-mobile').text(pageNames[currentPath]);
    }
});



$(document).ready(function() {
    $(document).on('click', function() {
        $('.dropdown-content').removeClass('active');
    });

    $('.dropdown-content').on('click', function(e) {
        e.stopPropagation();
    });

    $('.dropdown').on('click', function(e) {
        e.preventDefault();
        e.stopPropagation();

        $('.dropdown-content').not($(this).next()).removeClass('active');

        $(this).next('.dropdown-content').toggleClass('active');
    });
});

$(document).ready(function() {
    // Listen for scroll events
    $(window).scroll(function() {
      var scrollTop = $(this).scrollTop();
      var $primaryHeader = $('.primaryheader');
      var $navLinks = $('.nav-links-wrapper');
      var $exploreNav = $('#nav-open-button');

      if (scrollTop > 50) { // Adjust the scroll threshold as needed
        $primaryHeader.addClass('scrolled');
        $navLinks.addClass('hidden');
        $exploreNav.addClass('show');
      } else {
        $primaryHeader.removeClass('scrolled');
        $navLinks.removeClass('hidden');
        $exploreNav.removeClass('show');
      }
    });
  });



//Sidenavigation svg elements
loadsimpleSVGClass("triangles-sidenav", "sidenav-triangle-svg")
loadsimpleSVG("hp-left-slide-online", "hp-target")
loadsimpleSVG("attitude-2", "attitude-target")
loadsimpleSVG("knowledge-2", "knowledge-target")
